@@ -21,40 +21,38 @@
 # limitations under the License.
 #
 
-require(stats)
-require(utils)
-
 #' @rdname MOCS
 #' @title Method of Constant Stimuli (MOCS)
 #' @description MOCS performs either a yes/no or n-interval-forced-choice Method of
 #' Constant Stimuli test
 #' @param params A matrix where each row is \code{x y i n correct_n ll1 ll2 ... llm} where
-#'  * \code{x} is X coordinate of location.
-#'  * \code{y} is Y coordinate of location.
-#'  * \code{i} is a location number (assigned by caller).
-#'  * \code{n} is Number of times this location/luminance(s) should be repeated.
-#'  * \code{correct_n} is the index i of the luminance level (\code{lli}) that
+#'   * \code{x} is X coordinate of location
+#'   * \code{y} is Y coordinate of location
+#'   * \code{i} is a location number (assigned by caller)
+#'   * \code{n} is Number of times this location/luminance(s) should be repeated
+#'   * \code{correct_n} is the index i of the luminance level (\code{lli}) that
 #'       should be treated as a ``correct'' response (the correct interval). For a
 #'       standard MOCS, this will be 1; for a 2AFC, this will be 1 or 2. This number will
 #'       be in the range \code{[1,m]}.
-#'  * \code{lli} is the i'th luminance level to be used at this location for
+#'   * \code{lli} is the i'th luminance level to be used at this location for
 #'       interval i of the presentation in cd/\eqn{\mbox{m}^2}{m^2}. For a standard MOCS,
 #'       i=1, and the \code{params} matrix will have 5 columns. For a 2AFC, there will be
 #'       two lli's, and \code{params} will have 6 columns.
-#' 
+#'
 #' @param order Control the order in which the stimuli are presented.
-#'  * \code{"random"} Randomise the order of trials/locations.
-#'  * \code{"fixed"} Present each row of \code{params} in order of \code{1:nrow(params)}, ignoring the \code{n} (4th) column in \code{params}.
-#' 
+#'   * \code{"random"} Randomise the order of trials/locations.
+#'   * \code{"fixed"} Present each row of \code{params} in order of \code{1:nrow(params)}, ignoring the \code{n} (4th) column in \code{params}.
+#'
 #' @param responseWindowMeth Control time perimeter waits for response.
-#'  * \code{"speed"} After an average of the last \code{speedHistory} response times, with a minimum of \code{responseFloor}. Initially \code{responseFloor}.
-#'  * \code{"constant"} Always use \code{responseFloor}.
-#'  * \code{"forceKey"} Wait for a keyboard input.
+#'   * \code{"speed"} After an average of the last \code{speedHistory} response times, with a minimum of \code{responseFloor}. Initially #'       \code{responseFloor}.
+#'   * \code{"constant"} Always use \code{responseFloor}.
+#'   * \code{"forceKey"} Wait for a keyboard input.
+#'
 #' @param responseFloor Minimum response window (for any \code{responseWindowMeth} except \code{"forceKey"}).
 #' @param responseHistory Number of past yeses to average to get response window
 #'   (only used if \code{responseWindowMeth} is \code{"speed"}).
 #' @param keyHandler Function to get a keyboard input and returns as for \code{opiPresent}:
-#'   \code{list(err=\{NULL|msg\}, seen=\{TRUE|FALSE\}, time}. The parameters passed to
+#'   \code{err}, \code{seen} and \code{time}. The parameters passed to
 #'   the function are the correct interval number (column 4 of \code{params}), and the
 #'   result of \code{opiPresent}. See Examples.
 #' @param interStimMin Regardless of response, wait \code{runif(interStimMin, interStimMax)} ms.
@@ -84,6 +82,7 @@ require(utils)
 #' If the \code{checkFixationOK} function is present in a stimulus, then it is called after each
 #' presentation, and the result is ``anded'' with each stimulus in a trial to get a TRUE/FALSE
 #' for fixating on all stimuli in a trial.
+#' 
 #' @return Returns a data.frame with one row per stimulus copied from params with extra columns
 #' appended: checkFixation checks, and the return values from \code{opiPresent()}
 #' (see example). These last values will differ depending on which
@@ -96,7 +95,7 @@ require(utils)
 #'   * column 6: TRUE/FALSE was fixating for all presentations in this trial according to \code{checkFixationOK}
 #'   * column 7...: columns from params
 #'   * ...: columns from opiPresent return
-#' 
+#'
 #' @references
 #' A. Turpin, P.H. Artes and A.M. McKendrick. "The Open Perimetry Interface: An enabling tool for
 #' clinical visual psychophysics", Journal of Vision 12(11) 2012.
@@ -289,26 +288,26 @@ MOCS <- function(params = NA,
         }
 
         if (responseWindowMeth == "forceKey")
-          ret <- keyHandler(mocs[i, 6], ret)
+          res <- keyHandler(mocs[i, 6], res)
 
-        if (is.null(ret$err)) {
-            if (ret$seen)
+        if (is.null(res$err)) {
+            if (res$seen)
                 beep_function('correct')
             else
                 beep_function('incorrect')
 
-            if (ret$seen && responseWindowMeth == "speed")
-                respTimeHistory <- c(utils::tail(respTimeHistory, -1), ret$time)
+            if (res$seen && responseWindowMeth == "speed")
+                respTimeHistory <- c(utils::tail(respTimeHistory, -1), res$time)
         } else {
             warning("Opi Present return error in MOCS")
             error_count <- error_count + 1
         }
 
-        cat(sprintf(',%g,%g\n', ret$seen,  ret$time))
+        cat(sprintf(',%g,%g\n', res$seen,  res$time))
 
         Sys.sleep(stats::runif(1, min = interStimMin, max = interStimMax)/1000)
 
-        results <- rbind(results, c(mocs[i, 1:5], all_fixations_good, mocs[i, 6:ncol(mocs)], ret))
+        results <- rbind(results, c(mocs[i, 1:5], all_fixations_good, mocs[i, 6:ncol(mocs)], res))
     }
 
     if (error_count > 0)
